@@ -349,10 +349,10 @@ cpufreq_prefs_dialog_response_cb (CPUFreqPrefs *prefs,
         GError *error = NULL;
 
         if (response == GTK_RESPONSE_HELP) {
-		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (prefs->priv->dialog)),
-			"help:cpufreq-applet/cpufreq-applet-prefs",
-			gtk_get_current_event_time (),
-			&error);
+		gtk_show_uri_on_window (GTK_WINDOW (prefs->priv->dialog),
+		                        "help:cpufreq-applet/cpufreq-applet-prefs",
+		                        gtk_get_current_event_time (),
+		                        &error);
 
                 if (error) {
                         cpufreq_utils_display_error (_("Could not open help document"),
@@ -434,6 +434,9 @@ cpufreq_prefs_dialog_update (CPUFreqPrefs *prefs)
 					      TRUE);
 
 		break;
+	default:
+		g_assert_not_reached ();
+		break;
 	}
 }
 
